@@ -84,7 +84,8 @@ def read_svn_link(data):
 
     """
     split_byte = b" "
-    filetype, *src = data.split(split_byte)
+    first_line = data.split(b"\n")[0]
+    filetype, *src = first_line.split(split_byte)
     src = split_byte.join(src)
     return filetype, src
 
@@ -136,6 +137,13 @@ class FileState:
     svn_special_path_non_link_data: Optional[bytes] = None
     """keep track of non link file content with svn:special property set"""
 
+    # default value: 0, 1: set the flag, 2: remove the exec flag
+    executable: int = DEFAULT_FLAG
+    """keep track if file is executable when setting svn:executable property"""
+
+    link: bool = False
+    """keep track if file is a svn link when setting svn:special property"""
+
 
 class FileEditor:
     """File Editor in charge of updating file on disk and memory objects.
@@ -154,22 +162,19 @@ class FileEditor:
     def __init__(self, directory, rootpath, path, state: FileState):
         self.directory = directory
         self.path = path
-        # default value: 0, 1: set the flag, 2: remove the exec flag
-        self.executable = DEFAULT_FLAG
-        self.link = None
         self.fullpath = os.path.join(rootpath, path)
         self.state = state
 
     def change_prop(self, key, value):
         if key == properties.PROP_EXECUTABLE:
             if value is None:  # bit flip off
-                self.executable = NOEXEC_FLAG
+                self.state.executable = NOEXEC_FLAG
             else:
-                self.executable = EXEC_FLAG
+                self.state.executable = EXEC_FLAG
         elif key == properties.PROP_SPECIAL:
             # Possibly a symbolic link. We cannot check further at
             # that moment though, patch(s) not being applied yet
-            self.link = value is not None
+            self.state.link = value is not None
         elif key == SVN_PROPERTY_EOL:
             # backup end of line style for file
             self.state.eol_style = value
@@ -215,7 +220,7 @@ class FileEditor:
                 # real svn symlink for potential patching in later
                 # commits
                 sbuf = self.__make_svnlink()
-                self.link = True
+                self.state.link = True
             else:
                 with open(self.fullpath, "rb") as f:
                     sbuf = f.read()
@@ -236,16 +241,14 @@ class FileEditor:
           computation purposes)
 
         """
-        is_link = None
 
-        if self.link:
+        if self.state.link:
             # can only check now that the link is a real one
             # since patch has been applied
             is_link, src = is_file_an_svnlink_p(self.fullpath)
             if is_link:
                 self.__make_symlink(src)
             else:  # not a real link ...
-                self.link = False
                 # when a file with the svn:special property set is not a svn link,
                 # the svn export operation will extract a truncated version of that file
                 # if it contains a null byte (see create_special_file_from_stream
@@ -271,10 +274,11 @@ class FileEditor:
                 f.write(self.state.svn_special_path_non_link_data)
                 self.state.svn_special_path_non_link_data = None
 
+        is_link = os.path.islink(self.fullpath)
         if not is_link:  # if a link, do nothing regarding flag
-            if self.executable == EXEC_FLAG:
+            if self.state.executable == EXEC_FLAG:
                 os.chmod(self.fullpath, 0o755)
-            elif self.executable == NOEXEC_FLAG:
+            elif self.state.executable == NOEXEC_FLAG:
                 os.chmod(self.fullpath, 0o644)
 
         # And now compute file's checksums
